/**
 * Implement an edge in a weighted graph
 * @author Mark Stehlik
 */

public class Edge
{
	private int source;
	private int dest;
	private double cost;

	/**
	 * Constructs an edge from s to d with default cost (-1)
	 * @param s the source vertex
	 * @param d the destination vertex
	 */
	public Edge(int s, int d)
	{
		this(s,d,-1);
	}

	/**
	 * Constructs an edge from s to d with cost c
	 * @param s the source vertex
	 * @param d the destination vertex
	 * @param c the cost of this edge
	 */
	public Edge(int s, int d, double c)
	{
		source = s;
		dest = d;
		cost = c;
	}

	/**
	 * Constructs a copy of the edge e
	 * @param e the edge to duplicate
	 */
	public Edge(Edge e)
	{
		this.source = e.source;
		this.dest = e.dest;
		this.cost = e.cost;
	}

    /**
     * Returns the source vertex of the edge
     * @return this edge's source vertex
     */
	public int getSource()
	{
		return source;
	}

    /**
     * Returns the destination vertex of the edge
     * @return this edge's destination vertex
     */
	public int getDest()
	{
		return dest;
	}

    /**
     * Returns the cost of the edge
     * @return this edge's cost
     */
	public double getCost()
	{
		return cost;
	}

    /**
     * Sets the cost of this edge to a new cost
     * @param c this edge's new cost
     */
	public void setCost(double c)
	{
		cost = c;
	}

    /**
     * Compares two edges for equality.
     * Returns true if this edge's source and destination are the same as the parameter's
     * @param o the object to compare against
     * @return true if the compared edges have the same source vertex and the same
     * destination vertex; false otherwise
     */
	public boolean equals(Object o)
	{
		Edge e = (Edge) o;
		return (source == e.source && dest == e.dest);
	}

    /**
     * Returns a string representing this edge
     * @return this edge's string representation
     */
	public String toString()
	{
		return ("[" + source + "->" + dest + " " + cost + "]");
	}
}
